// -----------------------------------------------------------------------------
//
//   ABOUT: "Development Set" for geometry prototyping
//  AUTHOR: Julius aka Julio César (juliocesar2k7@gmail.com)
// LICENSE: GPL v2
//     URL: none
//
//    DATE: June 2022 to...
//
//
// CONTENT:
//
//  - lava1: Scrolling, Swinging, Pipes
//  - slime1: Scrolling, Swinging, Pipes
//  - water1: Blue 100%, 80%, 60% & 40% opacity (nolightmap)
//
// -----------------------------------------------------------------------------


// -----------------------------------------------------------------------------
// Lava and Slime with Glow (LIGHTMAPPED)
//
//  Orange: (20,85,100 HSV) (255,111,38 RGB) (1.0 0.44 0.15 ized)
//   Green: (88,90,70 HSV)  (104,179,18 RGB) (0.41 0.70 0.07 ized)
// -----------------------------------------------------------------------------

// Waves + Turbulence + Scroll

textures/devel_liquid/lava1_Scroll
{
    qer_editorImage textures/devel/liquid/lava1_qer1.tga
    //qer_trans 0.75

    q3map_lightRGB 1.0 0.44 0.15
    q3map_backSplash 0 0          // <percentage> <distance> (5 23 as default)
    q3map_surfaceLight 200

    cull none

    // deformVertexes <type> <div> <func>  <base> <amplitude> <phase> <freq>
    q3map_tessSize 64
    deformVertexes wave 512 sin 0 4 0.0 0.5

    surfaceparm trans             // NO VIS-blocking, NO Shadow casting
    surfaceparm lava              // sets lava physics

    {
        map textures/devel/liquid/lava1.tga
        rgbGen identity
        tcMod turb 0 0.1 0 0.05   // <base> <amplitude> <phase> <freq>
        tcMod scroll 0.0 0.15     // <Xspeed> <Yspeed> in textures per second
        blendFunc blend
    }
    {
        map $lightmap
        rgbGen identity
        blendFunc filter
    }
}

textures/devel_liquid/slime1_Scroll
{
    qer_editorImage textures/devel/liquid/slime1_qer1.tga
    //qer_trans 0.75

    q3map_lightRGB 0.41 0.70 0.07
    q3map_backSplash 0 0
    q3map_surfaceLight 125

    cull none

    // deformVertexes <type> <div> <func>  <base> <amplitude> <phase> <freq>
    q3map_tessSize 64
    deformVertexes wave 512 sin 0 4 0.0 0.5

    surfaceparm trans
    surfaceparm slime

    {
        map textures/devel/liquid/slime1.tga
        rgbGen identity
        tcMod turb 0 0.1 0 0.05
        tcMod scroll 0.0 0.15
        blendFunc blend
    }
    {
        map $lightmap
        rgbGen identity
        blendFunc filter
    }
}

// Waves + Turbulence

textures/devel_liquid/lava1_Swing
{
    qer_editorImage textures/devel/liquid/lava1_qer2.tga
    //qer_trans 0.75

    q3map_lightRGB 1.0 0.44 0.15
    q3map_backSplash 0 0
    q3map_surfaceLight 200

    cull none

    // deformVertexes <type> <div> <func>  <base> <amplitude> <phase> <freq>
    q3map_tessSize 64
    deformVertexes wave 512 sin 0 4 0.0 0.5

    surfaceparm trans
    surfaceparm lava

    {
        map textures/devel/liquid/lava1.tga
        rgbGen identity
        tcMod turb 0 0.1 0 0.05
        blendFunc blend
    }
    {
        map $lightmap
        rgbGen identity
        blendFunc filter
    }
}

textures/devel_liquid/slime1_Swing
{
    qer_editorImage textures/devel/liquid/slime1_qer2.tga
    //qer_trans 0.75

    q3map_lightRGB 0.41 0.70 0.07
    q3map_backSplash 0 0
    q3map_surfaceLight 125

    cull none

    // deformVertexes <type> <div> <func>  <base> <amplitude> <phase> <freq>
    q3map_tessSize 64
    deformVertexes wave 512 sin 0 4 0.0 0.5

    surfaceparm trans
    surfaceparm slime

    {
        map textures/devel/liquid/slime1.tga
        rgbGen identity
        tcMod turb 0 0.1 0 0.05
        blendFunc blend
    }
    {
        map $lightmap
        rgbGen identity
        blendFunc filter
    }
}

// Bulge + Scroll (VERTEX-LIT)

textures/devel_liquid/lava1_Pipe
{
    qer_editorImage textures/devel/liquid/lava1_qer3.tga
    //qer_trans 0.75

    q3map_lightRGB 1.0 0.44 0.15
    q3map_backSplash 0 0
    q3map_surfaceLight 200

    cull none

    // deformVertexes bulge  <bulgeS> <bulgeT>  <bulgeSpeed>
    deformVertexes bulge 0 2 4.0

    surfaceparm trans
    surfaceparm nonsolid
    surfaceparm nolightmap

    {
        map textures/devel/liquid/lava1.tga
        rgbGen vertex
        tcMod scroll -0.30 -0.60
        //blendFunc blend         // looks bad for cylinders (sort order)
    }
}

textures/devel_liquid/slime1_Pipe
{
    qer_editorImage textures/devel/liquid/slime1_qer3.tga
    //qer_trans 0.75

    q3map_lightRGB 0.41 0.70 0.07
    q3map_backSplash 0 0
    q3map_surfaceLight 125

    cull none

    // deformVertexes bulge  <bulgeS> <bulgeT>  <bulgeSpeed>
    deformVertexes bulge 0 2 4.0

    surfaceparm trans
    surfaceparm nonsolid
    surfaceparm nolightmap

    {
        map textures/devel/liquid/slime1.tga
        rgbGen vertex
        tcMod scroll -0.30 -0.60
        //blendFunc blend         // looks bad for cylinders (sort order)
    }
}

// -----------------------------------------------------------------------------
// Water Pipe (temp grid texture)
// -----------------------------------------------------------------------------

// Bulge + Scroll

textures/devel_liquid/water_Pipe
{
    qer_editorImage textures/devel/misc/trans_grid.tga
    //qer_trans 0.50

    cull none
    noPicMip

    // deformVertexes bulge  <bulgeS> <bulgeT>  <bulgeSpeed>
    deformVertexes bulge 0 2 4.0

    surfaceparm trans
    surfaceparm nonsolid
    surfaceparm nolightmap

    {
        map textures/devel/misc/trans_grid.tga
        rgbGen identity
        tcMod scroll -0.30 -0.60
        // (source * 1) + (dest * (1 - source))  <= Additive + Inverse Multip
        blendFunc GL_ONE GL_ONE_MINUS_SRC_COLOR
    }
}

// -----------------------------------------------------------------------------
// Water1: Blue (NOLIGHTMAP)
//
//  Blue: (196 10 100 HSV) (230 248 255 RGB) (0.90 0.97 1.0 ized)
//        (196 15 100 HSV) (217 245 255 RGB) (0.85 0.96 1.0 ized)
//        (196 20 100 HSV) (204 241 255 RGB) (0.80 0.94 1.0 ized)
//        (196 25 100 HSV) (191 238 255 RGB) (0.75 0.93 1.0 ized)
// -----------------------------------------------------------------------------

// dpWater + Scroll

textures/devel_liquid/water1_blue_100%
{
    qer_editorImage textures/devel/liquid/water1_blue_qer.tga
    //qer_trans 0.80

    q3map_cloneShader devel_liquid/water1_blue_BACK

    q3map_tcMod rotate -30        // 0º = West, -90º = North

    surfaceparm trans             // NO VIS-blocking, NO Shadow casting
    surfaceparm water             // sets water physics
    surfaceparm nolightmap        // doesn't reveive shadows

    //      min max  distort  tint (15%)     tint   alpha
    dpWater 1.0 1.0  5.0 3.0  0.85 0.96 1.0  1 1 1  0.20

    {
        map textures/devel/liquid/water1_blue.tga
        rgbGen identity
        alphaGen vertex
        tcMod scale 0.50 1.50
        tcMod scroll 0.0 0.40
    }
}

textures/devel_liquid/water1_blue_80%
{
    qer_editorImage textures/devel/liquid/water1_blue_qer.tga
    qer_trans 0.80

    q3map_cloneShader devel_liquid/water1_blue_BACK

    q3map_tcMod rotate -30

    surfaceparm trans
    surfaceparm water
    surfaceparm nolightmap

    //      min  max  distort  tint (15%)     tint   alpha
    dpWater 0.80 1.0  5.0 3.0  0.85 0.96 1.0  1 1 1  0.20

    {
        map textures/devel/liquid/water1_blue.tga
        rgbGen identity
        alphaGen vertex
        tcMod scale 0.50 1.50
        tcMod scroll 0.0 0.40
    }
}

textures/devel_liquid/water1_blue_60%
{
    qer_editorImage textures/devel/liquid/water1_blue_qer.tga
    qer_trans 0.60

    q3map_cloneShader devel_liquid/water1_blue_BACK

    q3map_tcMod rotate -30

    surfaceparm trans
    surfaceparm water
    surfaceparm nolightmap

    //      min  max  distort  tint (15%)     tint   alpha
    dpWater 0.60 1.0  5.0 3.0  0.85 0.96 1.0  1 1 1  0.20

    {
        map textures/devel/liquid/water1_blue.tga
        rgbGen identity
        alphaGen vertex
        tcMod scale 0.50 1.50
        tcMod scroll 0.0 0.40
    }
}

textures/devel_liquid/water1_blue_40%
{
    qer_editorImage textures/devel/liquid/water1_blue_qer.tga
    qer_trans 0.40

    q3map_cloneShader devel_liquid/water1_blue_BACK

    q3map_tcMod rotate -30

    surfaceparm trans
    surfaceparm water
    surfaceparm nolightmap

    //      min  max  distort  tint (15%)     tint   alpha
    dpWater 0.40 1.0  5.0 3.0  0.85 0.96 1.0  1 1 1  0.20

    {
        map textures/devel/liquid/water1_blue.tga
        rgbGen identity
        alphaGen vertex
        tcMod scale 0.50 1.50
        tcMod scroll 0.0 0.40
    }
}

// Back-side (FULL-BRIGHT)

devel_liquid/water1_blue_BACK
{
    q3map_invert

    q3map_tcMod rotate -30

    surfaceparm trans
    surfaceparm nolightmap

    // Refraction only:
    dpWater 0.0 0.0  5.0 0.0  0.85 0.96 1.0  1 1 1  0.25

    {
        map textures/devel/liquid/water1_blue.tga
        rgbGen identity
        alphaGen vertex
        tcMod scale 0.50 1.50
        tcMod scroll 0.0 0.40
    }
}

// EOF ------------------------------- EOF --------------------------------- EOF
