// -----------------------------------------------------------------------------
//
//   ABOUT: "Development Set" for geometry prototyping
//  AUTHOR: Julius aka Julio César (juliocesar2k7@gmail.com)
// LICENSE: GPL v2
//     URL: none
//
//    DATE: June 2022 to...
//
//
// CONTENT:
//
//  - Color grid: opaque and solid
//  - Trans grid: additive, solid and nonsolid
//
//  - Teleport grid: additive, nonsolid, light emitting
//  - Hexagonal grid: additive, solid and nonsolid, light emitting
//  - Ruler: blend, nonsolid
//
// -----------------------------------------------------------------------------


// -----------------------------------------------------------------------------
// Color Grid (Blender's UV grid) (LIGHTMAPPED)
// -----------------------------------------------------------------------------

textures/devel_misc/color_grid
{
    qer_editorImage textures/devel/misc/color_grid.tga

    {
        map textures/devel/misc/color_grid.tga
        rgbGen identity
    }
    {
        map $lightmap
        rgbGen identity
        blendFunc filter
    }
}

// -----------------------------------------------------------------------------
// Trans Grid (solid & nonsolid) (FULLBRIGHT)
// -----------------------------------------------------------------------------

textures/devel_misc/trans_grid
{
    qer_editorImage textures/devel/misc/trans_grid.tga
    qer_trans 0.25

    cull none                     // do not cull the back-side of the surface
    noPicMip                      // ignore gl_picmip cvar (texture resolution)

    surfaceparm trans             // NO VIS-blocking, NO Shadow casting
    surfaceparm nolightmap

    {
        map textures/devel/misc/trans_grid.tga
        rgbGen identity
        // (source * 1) + (dest * (1 - source))  <= Additive + Inverse Multip
        blendFunc GL_ONE GL_ONE_MINUS_SRC_COLOR
    }
}

textures/devel_misc/trans_grid_nonsolid
{
    qer_editorImage textures/devel/misc/trans_grid.tga
    qer_trans 0.25

    cull none
    noPicMip

    surfaceparm trans
    surfaceparm nonsolid
    surfaceparm nolightmap

    {
        map textures/devel/misc/trans_grid.tga
        rgbGen identity
        // (source * 1) + (dest * (1 - source))  <= Additive + Inverse Multip
        blendFunc GL_ONE GL_ONE_MINUS_SRC_COLOR
    }
}

// -----------------------------------------------------------------------------
// Teleport grid (nonsolid) (FULLBRIGHT)
//
//  Green: (120,90,100 HSV) (26,255,26 RGB) (0.10 1.0 0.10 ized)
//    Red: (5,100,100 HSV) (255,21,0 RGB) (1.0 0.08 0.0 ized)
// -----------------------------------------------------------------------------

// green

textures/devel_misc/tele_grid1
{
    qer_editorImage textures/devel/misc/tele_grid1.tga
    qer_trans 0.50

    q3map_lightRGB 0.10 1.0 0.10
    q3map_backSplash 0 0          // <percentage> <distance> (5 23 as default)
    q3map_surfaceLight 35

    cull none                     // do not cull the back-side of the surface
    noPicMip                      // ignore gl_picmip cvar (texture resolution)

    surfaceparm trans             // NO VIS-blocking, NO Shadow casting
    surfaceparm nonsolid
    surfaceparm nolightmap

    {
        map textures/devel/misc/tele_grid1.tga
        rgbGen identity
        tcMod stretch sin 0.75 0.25 0 0.20
        tcMod rotate -20
        // (source * 1) + (dest * (1 - source))  <= Additive + Inverse Multip
        blendFunc GL_ONE GL_ONE_MINUS_SRC_COLOR
    }
}

// red

textures/devel_misc/tele_grid2
{
    qer_editorImage textures/devel/misc/tele_grid2.tga
    qer_trans 0.50

    q3map_lightRGB 1.0 0.08 0.0
    q3map_backSplash 0 0
    q3map_surfaceLight 50

    cull none
    noPicMip

    surfaceparm trans
    surfaceparm nonsolid
    surfaceparm nolightmap

    {
        map textures/devel/misc/tele_grid2.tga
        rgbGen identity
        tcMod stretch sin 0.75 0.25 0.50 0.20    // phase shift of 0.5
        tcMod rotate 20
        // (source * 1) + (dest * (1 - source))  <= Additive + Inverse Multip
        blendFunc GL_ONE GL_ONE_MINUS_SRC_COLOR
    }
}

// -----------------------------------------------------------------------------
// Hexagonal grid (solid & nonsolid) (FULLBRIGHT)
//
//  Orange: ( 20  80 100 HSV) (255 119  51 RGB) (1.0 0.47 0.20 ized)
//    Blue: (200 100 100 HSV) (  0 170 255 RGB) (0.0 0.67 1.0  ized)
// -----------------------------------------------------------------------------

// orange

textures/devel_misc/hexa_grid1
{
    qer_editorImage textures/devel/misc/hexa_grid1.tga
    qer_trans 0.25

    q3map_lightRGB 1.0 0.47 0.20
    q3map_backSplash 0 0          // <percentage> <distance> (5 23 as default)
    q3map_surfaceLight 50

    cull none                     // do not cull the back-side of the surface
    noPicMip                      // ignore gl_picmip cvar (texture resolution)

    surfaceparm trans             // NO VIS-blocking, NO Shadow casting
    surfaceparm nolightmap

    {
        map textures/devel/misc/hexa_grid1.tga
        rgbGen identity
        //tcMod stretch sin 0.90 0.10 0 0.10
        tcMod scroll -0.05 0
        // (source * 1) + (dest * (1 - source))  <= Additive + Inverse Multip
        blendFunc GL_ONE GL_ONE_MINUS_SRC_COLOR
    }
}

textures/devel_misc/hexa_grid1_nonsolid
{
    qer_editorImage textures/devel/misc/hexa_grid1.tga
    qer_trans 0.25

    q3map_lightRGB 1.0 0.47 0.20
    q3map_backSplash 0 0
    q3map_surfaceLight 50

    cull none
    noPicMip

    surfaceparm trans
    surfaceparm nonsolid
    surfaceparm nolightmap

    {
        map textures/devel/misc/hexa_grid1.tga
        rgbGen identity
        //tcMod stretch sin 0.90 0.10 0 0.10
        tcMod scroll -0.05 0
        // (source * 1) + (dest * (1 - source))  <= Additive + Inverse Multip
        blendFunc GL_ONE GL_ONE_MINUS_SRC_COLOR
    }
}

// blue

textures/devel_misc/hexa_grid2
{
    qer_editorImage textures/devel/misc/hexa_grid2.tga
    qer_trans 0.25

    q3map_lightRGB 0.0 0.67 1.0
    q3map_backSplash 0 0
    q3map_surfaceLight 60

    cull none
    noPicMip

    surfaceparm trans
    surfaceparm nolightmap

    {
        map textures/devel/misc/hexa_grid2.tga
        rgbGen identity
        tcMod stretch sin 0.90 0.10 0 0.10
        //tcMod scroll 0.05 0
        // (source * 1) + (dest * (1 - source))  <= Additive + Inverse Multip
        blendFunc GL_ONE GL_ONE_MINUS_SRC_COLOR
    }
}

textures/devel_misc/hexa_grid2_nonsolid
{
    qer_editorImage textures/devel/misc/hexa_grid2.tga
    qer_trans 0.25

    q3map_lightRGB 0.0 0.67 1.0
    q3map_backSplash 0 0
    q3map_surfaceLight 60

    cull none
    noPicMip

    surfaceparm trans
    surfaceparm nonsolid
    surfaceparm nolightmap

    {
        map textures/devel/misc/hexa_grid2.tga
        rgbGen identity
        tcMod stretch sin 0.90 0.10 0 0.10
        //tcMod scroll 0.05 0
        // (source * 1) + (dest * (1 - source))  <= Additive + Inverse Multip
        blendFunc GL_ONE GL_ONE_MINUS_SRC_COLOR
    }
}

// -----------------------------------------------------------------------------
//  Ruler (nonsolid) (LIGHTMAPPED)
// -----------------------------------------------------------------------------

textures/devel_misc/ruler
{
    qer_editorImage textures/devel/misc/ruler.tga
    qer_alphaFunc gequal 0.25

    //dpGlossIntensityMod 0.50
    //dpGlossExponentMod 1.0

    polygonOffset                 // avoid z-fight (renders separated from the surface)
    noPicMip                      // ignore gl_picmip client cvar (textures resolution)

    surfaceparm trans             // NO VIS-blocking & NO Shadow-casting
    surfaceparm nonsolid

    {
        map textures/devel/misc/ruler.tga
        rgbGen identity
        blendFunc blend
    }
    {
        map $lightmap
        rgbGen identity
        blendFunc filter
    }
}

// EOF ------------------------------- EOF --------------------------------- EOF
