// -----------------------------------------------------------------------------
//
//   ABOUT: "Development Set" for geometry prototyping
//  AUTHOR: Julius aka Julio César (juliocesar2k7@gmail.com)
// LICENSE: GPL v2
//     URL: none
//
//    DATE: June 2022 to...
//
//
// CONTENT:
//
//  - Sprites: Testing Area, Wip Map, Question mark, Exclamation mark
//
//
// NOTES:
//
//  - "deformVertexes autosprite" works for brushes, patch meshes (*) and
//    models (**).
//
//     (*) Patches must be coplanar. If they are not then "cull none" is required.
//
//    (**) Models must be compiled with "cull none" (wich makes them two-sided)
//         and without "deformVertexes autosprite" (which would produce empty
//         files).
//
//        "cull none" can be omitted for ASE but not for OBJ models.
//
// -----------------------------------------------------------------------------


// -----------------------------------------------------------------------------
//  Sprites (FULLBRIGHT)
// -----------------------------------------------------------------------------

// "TESTING AREA" (zooming)

textures/devel_sprite/sprite1
{
    qer_editorImage textures/devel/sprite/sprite1.tga
    qer_alphaFunc gequal 0.5

    noPicMip                       // ignore gl_picmip client cvar (textures resolution)
    cull none                      // do not cull the back-side of the surface
    deformVertexes autosprite      // always appears oriented to the player's view

    surfaceparm trans
    surfaceparm nonsolid
    surfaceparm nolightmap

    // tcMod stretch  <func>  <base> <amplitude> <phase> <freq>
    //  <base> starting size (1=full size)
    //  <amplitude> amount to add/substract to <base>

    {
        clampMap textures/devel/sprite/sprite1.tga
        rgbGen identity
        tcMod stretch sin 0.90 0.10 0 1.25
        blendFunc blend
    }
}

// "WIP MAP" (zooming)

textures/devel_sprite/sprite2
{
    qer_editorImage textures/devel/sprite/sprite2.tga
    qer_alphaFunc gequal 0.5

    noPicMip
    cull none
    deformVertexes autosprite

    surfaceparm trans
    surfaceparm nonsolid
    surfaceparm nolightmap

    // tcMod stretch  <func>  <base> <amplitude> <phase> <freq>
    //  <base> starting size (1=full size)
    //  <amplitude> amount to add/substract to <base>

    {
        clampMap textures/devel/sprite/sprite2.tga
        rgbGen identity
        tcMod stretch sin 0.90 0.10 0 1.25
        blendFunc blend
    }
}

// QUESTION mark (zooming)

textures/devel_sprite/sprite3
{
    qer_editorImage textures/devel/sprite/sprite3.tga
    qer_alphaFunc gequal 0.5

    noPicMip
    cull none
    deformVertexes autosprite

    surfaceparm trans
    surfaceparm nonsolid
    surfaceparm nolightmap

    // tcMod stretch  <func>  <base> <amplitude> <phase> <freq>
    //  <base> starting size (1=full size)
    //  <amplitude> amount to add/substract to <base>

    {
        clampMap textures/devel/sprite/sprite3.tga
        rgbGen identity
        tcMod stretch sin 0.85 0.15 0 1.25
        blendFunc blend
    }
}

// EXCLAMATION mark (zooming)

textures/devel_sprite/sprite4
{
    qer_editorImage textures/devel/sprite/sprite4.tga
    qer_alphaFunc gequal 0.5

    noPicMip
    cull none
    deformVertexes autosprite

    surfaceparm trans
    surfaceparm nonsolid
    surfaceparm nolightmap

    // tcMod stretch  <func>  <base> <amplitude> <phase> <freq>
    //  <base> starting size (1=full size)
    //  <amplitude> amount to add/substract to <base>

    {
        clampMap textures/devel/sprite/sprite4.tga
        rgbGen identity
        tcMod stretch sin 0.85 0.15 0 1.25
        blendFunc blend
    }
}

// EOF ------------------------------- EOF --------------------------------- EOF
